@@ -34,8 +34,8 @@
 #'   \code{\link{sprintf}}.
 #' @param ypos.mult numeric Multiplier constant used to scale returned
 #'   \code{y} values.
-#' @param ypos.fixed numeric If not \code{NULL} used a constant value returned
-#'   in \code{y}.
+#' @param xpos.fixed,ypos.fixed numeric If not \code{NULL} used a constant value returned
+#'   in \code{x} or \code{y}.
 #'
 #' @return A data frame with one row for each waveband object in the argument
 #' to \code{w.band}. Wavebeand outside the range of the spectral data are
@@ -58,6 +58,7 @@
 #'   \item{y}{ypos.fixed or top of data, adjusted by \code{ypos.mult}}
 #'   \item{wb.color}{color of the w.band}
 #'   \item{wb.name}{label of w.band}
+#'   \item{BW.color}{\code{black_or_white(wb.color)}}
 #' }
 #'
 #' @section Default aesthetics:
@@ -86,12 +87,19 @@
 #' library(ggplot2)
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
 #' ggplot(sun.spct) +
-#'   stat_wb_mean(w.band = VIS_bands()) +
-#'   stat_wb_e_sirrad(w.band = VIS_bands(),
-#'                   geom = "text", angle = 90, size = 4,
+#'   stat_wb_column(w.band = VIS_bands()) +
+#'   stat_wb_e_sirrad(w.band = VIS_bands(), angle = 90, size = 4,
 #'                   label.fmt = "%1.2f", ypos.fixed = 0.1) +
 #'   geom_line() +
-#'   scale_fill_identity()
+#'   scale_fill_identity() + scale_color_identity()
+#'
+#' ggplot(sun.spct, unit.out = "photon") +
+#'   geom_line() +
+#'   stat_wb_hbar(w.band = PAR(), size = 1) +
+#'   stat_wb_q_sirrad(aes(color = ..wb.color..),
+#'                    w.band = PAR(), label.fmt = "mean = %.3g",
+#'                    ypos.mult = 1, xpos.fixed = 390, hjust = 1) +
+#'   scale_color_identity()
 #'
 #' @export
 #' @family stats functions
@@ -104,6 +112,7 @@ stat_wb_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                        label.mult = 1,
                        label.fmt = "%.3g",
                        ypos.mult = 0.55,
+                       xpos.fixed = NULL,
                        ypos.fixed = NULL,
                        position = "identity", na.rm = FALSE, show.legend = NA,
                        inherit.aes = TRUE, ...) {
@@ -117,6 +126,7 @@ stat_wb_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                   label.mult = label.mult,
                   label.fmt = label.fmt,
                   ypos.mult = ypos.mult,
+                  xpos.fixed = xpos.fixed,
                   ypos.fixed = ypos.fixed,
                   na.rm = na.rm,
                   ...)
@@ -133,6 +143,7 @@ stat_wb_e_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                            label.mult = 1,
                            label.fmt = "%.3g",
                            ypos.mult = 0.55,
+                           xpos.fixed = NULL,
                            ypos.fixed = NULL,
                            position = "identity", na.rm = FALSE, show.legend = NA,
                            inherit.aes = TRUE, ...) {
@@ -146,6 +157,7 @@ stat_wb_e_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                   label.mult = label.mult,
                   label.fmt = label.fmt,
                   ypos.mult = ypos.mult,
+                  xpos.fixed = xpos.fixed,
                   ypos.fixed = ypos.fixed,
                   na.rm = na.rm,
                   ...)
@@ -161,7 +173,8 @@ stat_wb_q_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                            label.qty = "mean",
                            label.mult = 1,
                            label.fmt = "%.3g",
-                           ypos.mult = 0.55,
+                           ypos.mult = 1.07,
+                           xpos.fixed = NULL,
                            ypos.fixed = NULL,
                            position = "identity", na.rm = FALSE, show.legend = NA,
                            inherit.aes = TRUE, ...) {
@@ -175,6 +188,7 @@ stat_wb_q_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                   label.mult = label.mult,
                   label.fmt = label.fmt,
                   ypos.mult = ypos.mult,
+                  xpos.fixed = xpos.fixed,
                   ypos.fixed = ypos.fixed,
                   na.rm = na.rm,
                   ...)
@@ -196,6 +210,7 @@ StatWbSIrrad <-
                                             label.mult,
                                             label.fmt,
                                             ypos.mult,
+                                            xpos.fixed,
                                             ypos.fixed) {
                      if (length(w.band) == 0) {
                        w.band <- waveband(data$x)
@@ -241,9 +256,13 @@ StatWbSIrrad <-
                                                     ymin = min(data$y),
                                                     ymean = ymean.tmp,
                                                     wb.color = color(wb),
-                                                    wb.name = labels(wb)$label)
+                                                    wb.name = labels(wb)$label,
+                                                    BW.color = black_or_white(color(wb)))
                                          )
                      }
+                     if (!is.null(xpos.fixed)) {
+                       integ.df$x <- xpos.fixed
+                     }
                      if (is.null(ypos.fixed)) {
                        integ.df$y <- with(integ.df, ymin + (ymean - ymin) * ypos.mult)
                      } else {
@@ -259,7 +278,8 @@ StatWbSIrrad <-
                                               ymin = 0,
                                               ymax = ..ymean..,
                                               yintercept = ..ymean..,
-                                              fill = ..wb.color..),
+                                              fill = ..wb.color..,
+                                              color = ..BW.color..),
                    required_aes = c("x", "y")
   )
 
